@@ -32,7 +32,7 @@
 
 #include "debugger.h"
 #include "fuse.h"
-#include "memory.h"
+#include "memory_pages.h"
 
 /* Used to flag whether we're after a DD or FD prefix */
 enum hl_type { USE_HL, USE_IX, USE_IY };
