@@ -5,6 +5,7 @@
    Copyright (c) 2015 Stuart Brady
    Copyright (c) 2015-2017 Gergely Szasz
    Copyright (c) 2015 Stefano Bodrato
+   Copyright (c) 2017 Fredrick Meunier
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -48,6 +49,7 @@
 #include "peripherals/if1.h"
 #include "peripherals/if2.h"
 #include "peripherals/joystick.h"
+#include "peripherals/multiface.h"
 #include "profile.h"
 #include "psg.h"
 #include "rzx.h"
@@ -272,9 +274,12 @@ MENU_CALLBACK_WITH_ACTION( menu_options_selectroms_peripheral_select )
   case  3: menu_select_peripheral_roms( "+D",              2, 1 ); return;
   case  4: menu_select_peripheral_roms( "Didaktik 80",     3, 1 ); return;
   case  5: menu_select_peripheral_roms( "DISCiPLE",        4, 1 ); return;
-  case  6: menu_select_peripheral_roms( "Opus Discovery",  5, 1 ); return;
-  case  7: menu_select_peripheral_roms( "SpeccyBoot",      6, 1 ); return;
-  case  8: menu_select_peripheral_roms( "uSource",         7, 1 ); return;
+  case  6: menu_select_peripheral_roms( "Multiface One",   5, 1 ); return;
+  case  7: menu_select_peripheral_roms( "Multiface 128",   6, 1 ); return;
+  case  8: menu_select_peripheral_roms( "Multiface 3",     7, 1 ); return;
+  case  9: menu_select_peripheral_roms( "Opus Discovery",  8, 1 ); return;
+  case 10: menu_select_peripheral_roms( "SpeccyBoot",      9, 1 ); return;
+  case 11: menu_select_peripheral_roms( "uSource",        10, 1 ); return;
 
   }
 
@@ -338,6 +343,12 @@ MENU_CALLBACK( menu_machine_nmi )
   event_add( 0, z80_nmi_event );
 }
 
+MENU_CALLBACK( menu_machine_multifaceredbutton )
+{
+  ui_widget_finish();
+  multiface_red_button();
+}
+
 MENU_CALLBACK( menu_media_tape_open )
 {
   char *filename;
