@@ -2,8 +2,6 @@
    Copyright (c) 2005-2016 Philip Kendall
    Copyright (c) 2015 Stuart Brady
 
-   $Id: periph.c 5489 2016-05-17 20:34:24Z pak21 $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -33,6 +31,7 @@
 #include "fuse.h"
 #include "periph.h"
 #include "peripherals/if1.h"
+#include "peripherals/multiface.h"
 #include "peripherals/ula.h"
 #include "rzx.h"
 #include "settings.h"
@@ -451,6 +450,7 @@ periph_update( void )
   update_cartridge_menu();
   update_ide_menu();
   if1_update_menu();
+  multiface_status_update();
   specplus3_765_update_fdd();
   machine_current->memory_map();
 
