@@ -41,6 +41,8 @@ typedef enum periph_type {
   PERIPH_TYPE_BETA128,        /* Beta128 disk interface */
   PERIPH_TYPE_BETA128_PENTAGON, /* Beta128 disk interface as found on the original Pentagon */
   PERIPH_TYPE_BETA128_PENTAGON_LATE, /* Beta128 disk interface as found on later Pentagons */
+  PERIPH_TYPE_COVOX_DD,       /* Covox interface on port #dd */
+  PERIPH_TYPE_COVOX_FB,       /* Covox interface on port #fb */
   PERIPH_TYPE_DIVIDE,         /* DivIDE interface */
   PERIPH_TYPE_PLUSD,          /* +D disk interface */
   PERIPH_TYPE_DIDAKTIK80,     /* Didaktik 40/80 disk interface */
@@ -56,6 +58,9 @@ typedef enum periph_type {
 
   PERIPH_TYPE_KEMPSTON_MOUSE, /* Kempston mouse */
   PERIPH_TYPE_MELODIK,        /* Melodik interface */
+  PERIPH_TYPE_MULTIFACE_1,    /* Multiface 1 */
+  PERIPH_TYPE_MULTIFACE_128,  /* Multiface 128 */
+  PERIPH_TYPE_MULTIFACE_3,    /* Multiface 3 */
   PERIPH_TYPE_OPUS,           /* Opus disk interface */
   PERIPH_TYPE_PARALLEL_PRINTER, /* +2A/+3 parallel printer */
   PERIPH_TYPE_PENTAGON1024_MEMORY, /* Pentagon 1024-style memory paging */
