@@ -3,8 +3,6 @@
    Copyright (c) 2015 Stuart Brady
    Copyright (c) 2016 Fredrick Meunier
 
-   $Id: ula.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -141,7 +139,7 @@ get_1ffd( void )
 static void
 set_1ffd( libspectrum_dword value )
 {
-  specplus3_memoryport2_write( 0, value );
+  specplus3_memoryport2_write_internal( 0, value );
 }
 
 static int
