@@ -1,8 +1,6 @@
 /* profile.c: Z80 profiler
    Copyright (c) 2005-2016 Philip Kendall
 
-   $Id: profile.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -89,8 +87,8 @@ profile_start( void )
   init_profiling_counters();
 
   /* Schedule an event to ensure that the main z80 emulation loop recognises
-     profiling is turned on; otherwise problems occur if we we started while
-     the debugger was active (bug #1530345) */
+     profiling is turned on; otherwise problems occur if we started while
+     the debugger was active (bug #54) */
   event_add( tstates, event_type_null );
 
   ui_menu_activate( UI_MENU_ITEM_MACHINE_PROFILER, 1 );
