@@ -2,8 +2,6 @@
    Copyright (c) 2003-2013 Philip Kendall
    Copyright (c) 2015 Stuart Brady
 
-   $Id: binary.c 5434 2016-05-01 04:22:45Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -34,7 +32,7 @@
 
 #include "fuse.h"
 #include "gtkinternals.h"
-#include "memory.h"
+#include "memory_pages.h"
 #include "menu.h"
 #include "ui/ui.h"
 #include "utils.h"
